# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-22 12:38
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Profile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('other_name', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('about', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('employer', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('position', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('gender', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('ethnicity', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('facebook', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('twitter', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('linkedin', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('blog', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('image', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('cover_image', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
