# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-22 15:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('people', '0002_auto_20170822_1522'),
    ]

    operations = [
        migrations.AlterField(
            model_name='profile',
            name='security_question',
            field=models.CharField(blank=True, choices=[(b'first_pet_name', b'What was the name of your first pet?')], help_text=b'', max_length=100, null=True),
        ),
    ]
