# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-22 15:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('people', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='profile',
            name='email_activation_code',
            field=models.TextField(blank=True, help_text=b'', null=True),
        ),
        migrations.AddField(
            model_name='profile',
            name='mobile',
            field=models.CharField(blank=True, help_text=b'', max_length=20, null=True),
        ),
        migrations.AddField(
            model_name='profile',
            name='mobile_activation_code',
            field=models.CharField(blank=True, help_text=b'', max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='profile',
            name='security_question',
            field=models.CharField(blank=True, help_text=b'', max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='profile',
            name='security_question_answer',
            field=models.CharField(blank=True, help_text=b'', max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='profile',
            name='two_facter_enabled',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='profile',
            name='about',
            field=models.TextField(blank=True, help_text=b'', null=True),
        ),
    ]
